Authors
=======

Please note: This is only a implementation in python and does not claim any credit towards the actual design_ of SVS.

The Names of all authors associated with this implementation project are below:

  * *Justin C Presley* (justincpresley_)

Special Mentions:

  * *Xinyu Ma* (zjkmxy_) helped formed the TLV structure used in SVS

.. _design: https://named-data.github.io/StateVectorSync/
.. _justincpresley: https://github.com/justincpresley
.. _zjkmxy: https://github.com/zjkmxy